Crate simplicityhl

Crate simplicityhl 

Library for parsing and compiling SimplicityHL

Re-exports

pub extern crate either;
pub extern crate simplicity;

Re-exports

pub use crate::types::ResolvedType;
pub use crate::unstable::UnstableFeature;
pub use crate::unstable::UnstableFeatures;
pub use crate::value::Value;
pub use simplicity::elements;

Modules

array
ast
compile
Compile the parsed ast into a simplicity program
debug
driver
The driver module is responsible for module resolution and dependency management.
dummy_env
Dummy Elements environment for testing
error
jet
lexer
named
num
parse
This module contains the parsing code to convert the tokens into an AST.
pattern
resolution
source
str
Types for handling strings with invariants.
tracker
types
unstable
value

Macros

impl_eq_hash
Recursively implement PartialEq, Eq and std::hash::Hash using selected members of a given type. The type must have a getter method for each selected member.

Structs

AbiMeta
Arguments
Map of arguments.
CompiledProgram
A SimplicityHL program, compiled to Simplicity.
Parameters
Map of parameters.
SatisfiedProgram
A SimplicityHL program, compiled to Simplicity and satisfied with witness data.
TemplateProgram
The template of a SimplicityHL program.
WitnessTypes
Map of witness types.
WitnessValues
Map of witness values.