pub struct BTreeSlice<'a, A>(/* private fields */);Expand description
View of a slice as a balanced binary tree.
Each node is labelled with a slice. Leaves contain single elements.
The tree is right-associative:
&[a b c] becomes &[a] (&[b] &[c]).
The tree is empty if the slice is empty.
Implementations
Sourceimpl<'a, A> BTreeSlice<'a, A>
impl<'a, A> BTreeSlice<'a, A>
Sourcepub fn from_slice(slice: &'a [A]) -> Self
pub fn from_slice(slice: &'a [A]) -> Self
View the slice as a balanced binary tree.
Sourceimpl<A: Clone> BTreeSlice<'_, A>
impl<A: Clone> BTreeSlice<'_, A>