Module num

Module num 

Structs

NonZeroPow2Usize
An integer that is known to be a power of two with nonzero exponent.
Pow2Usize
An integer that is known to be a power of two.
U256
A 256-bit unsigned integer.

Enums

ParseIntError
Reimplementation of std::num::ParseIntError that we can construct.