Pow2Usize

Struct Pow2Usize 

pub struct Pow2Usize(/* private fields */);
An integer that is known to be a power of two.

The integer is equal to 2^n for some n ≥ 0.

Implementations

Source

impl Pow2Usize

pub const ONE: Self

Smallest power of two.

pub const fn new(n: usize) -> Option<Self>

Create a power of two.

pub const fn new_unchecked(n: usize) -> Self

Create a power of two.

Precondition

The value must be a power of two.

Panics

Panics may occur down the line if the precondition is not satisfied.

pub const fn log2(self) -> u32

Return the binary logarithm of the value.

The integer is equal to 2^n for some n ≥ 0. Return n.

pub const fn mul2(self) -> Self

Multiply the value by two. Return the next power of two.

The integer is equal to 2^n for some n ≥ 0. Return 2^(n + 1).

pub const fn checked_div2(self) -> Option<Self>

Divide the value by two. Return the previous power of two, if it exists.

  • If the integer is equal to 2^(n + 1) for some n ≥ 0, then return Some(2^n).
  • If the integer is equal to 2^0, then return None.
Source

impl Pow2Usize

pub const fn get(&self) -> usize

Access the value as a primitive type.