BasePattern

Enum BasePattern 

pub enum BasePattern {
    Ignore,
    Identifier(Identifier),
    Product(Arc<Self>, Arc<Self>),
}
Basic structure of a SimplicityHL value for pattern matching.

Variants



Ignore

Ignore: Match any value.

Used for matching values that are not assigned to a variable.



Identifier(Identifier)

Variable identifier: Match any value and bind it to an identifier.



Product(Arc<Self>, Arc<Self>)

Product: Match product value component-wise.

Implementations

Source

impl BasePattern

pub fn product(left: Self, right: Self) -> Self

Construct a product of patterns left and right.

pub fn as_identifier(&self) -> Option<&Identifier>

Access the identifier inside an identifier pattern.

pub fn contains(&self, identifier: &Identifier) -> bool

Check if the identifier is contained inside the pattern.

pub fn subsumes(&self, other: &Self) -> bool

Check if self subsumes the other pattern.

Subsumption
  • Ignore: _ subsumes every pattern.
  • Identifier: a subsumes b iff a = b
  • Product: (a1, a2) subsumes (b1, b2) iff a1 subsumes b1 and a2 subsumes b2.
Matching

If value v matches pattern p and pattern p' subsumes p, then v matches p'.

The subsuming pattern is more general than the subsumed pattern.

pub fn identifiers(&self) -> impl Iterator<Item = &Identifier>

Get an iterator over all identifiers inside the pattern.

pub fn contains_all<'a, I>(&self, identifiers: I) -> bool
where I: Iterator<Item = &'a Identifier>,

Check if all identifiers are contained inside the pattern.

pub fn covers(&self, other: &Self) -> bool

Check if self covers the other pattern in terms of variable names.

Coverage

Pattern p1 covers pattern p2 if p1 contains all variable names from p2.

pub fn is_ignore(&self) -> bool

Check if the pattern is the ignore pattern.

pub fn contains_ignore(&self) -> bool

Check if the pattern contains an ignore pattern.

pub fn translate<'brand, P: CoreExt<'brand>>( &self, ctx: &Context<'brand>, to: &Self, ) -> Option<PairBuilder<P>>

Compute a Simplicity expression that takes as input a value that matches the self pattern and that produces as output a value that matches the to pattern.

Panics

The to pattern contains ignore patterns: Every value matches the ignore pattern. This means there are infinitely many translating expressions from self to to. For instance, iden, iden & iden, (iden & iden) & iden, and so on. We enforce a unique translation by banning ignore from the to pattern.