pub struct CanonPath(/* private fields */);Expand description
A guaranteed, fully coanonicalized absolute path.
Implementations
Sourceimpl CanonPath
impl CanonPath
Sourcepub fn canonicalize(path: &Path) -> Result<Self, String>
pub fn canonicalize(path: &Path) -> Result<Self, String>
Safely resolves an absolute path via the OS and wraps it in a CanonPath.
Errors
Returns a String containing the OS error if the path does not exist or
cannot be accessed. The caller is expected to map this into a more specific
compiler diagnostic.
Sourcepub fn join(&self, parts: &[&str]) -> Result<Self, String>
pub fn join(&self, parts: &[&str]) -> Result<Self, String>
Appends a logical module path to this physical root directory and verifies it.
It automatically appends the .simf extension to the final path before asking
the OS to verify its existence.
Sourcepub fn starts_with(&self, path: &CanonPath) -> bool
pub fn starts_with(&self, path: &CanonPath) -> bool
Check if the current file is executing inside the context’s directory tree.
This prevents a file in /project_a/ from using a dependency meant for /project_b/
pub fn as_path(&self) -> &Path