Library for parsing and compiling SimplicityHL
Re-exports
pub extern crate either;pub extern crate simplicity;
Re-exports
pub use crate::types::ResolvedType;pub use crate::unstable::UnstableFeature;pub use crate::unstable::UnstableFeatures;pub use crate::value::Value;pub use simplicity::elements;
Modules
- array
- ast
- compile
- Compile the parsed ast into a simplicity program
- debug
- driver
- The
drivermodule is responsible for module resolution and dependency management. - dummy_
env - Dummy Elements environment for testing
- error
- jet
- lexer
- named
- num
- parse
- This module contains the parsing code to convert the tokens into an AST.
- pattern
- resolution
- source
- str
- Types for handling strings with invariants.
- tracker
- types
- unstable
- value
Macros
- impl_
eq_ hash - Recursively implement
PartialEq,Eqandstd::hash::Hashusing selected members of a given type. The type must have a getter method for each selected member.
Structs
- AbiMeta
- Arguments
- Map of arguments.
- Compiled
Program - A SimplicityHL program, compiled to Simplicity.
- Parameters
- Map of parameters.
- Satisfied
Program - A SimplicityHL program, compiled to Simplicity and satisfied with witness data.
- Template
Program - The template of a SimplicityHL program.
- Witness
Types - Map of witness types.
- Witness
Values - Map of witness values.