pub struct Pow2Usize(/* private fields */);Expand description
An integer that is known to be a power of two.
The integer is equal to 2^n for some n ≥ 0.
Implementations
Sourceimpl Pow2Usize
impl Pow2Usize
Sourcepub const fn new_unchecked(n: usize) -> Self
pub const fn new_unchecked(n: usize) -> Self
Sourcepub const fn log2(self) -> u32
pub const fn log2(self) -> u32
Return the binary logarithm of the value.
The integer is equal to 2^n for some n ≥ 0. Return n.
Sourcepub const fn mul2(self) -> Self
pub const fn mul2(self) -> Self
Multiply the value by two. Return the next power of two.
The integer is equal to 2^n for some n ≥ 0. Return 2^(n + 1).
Sourcepub const fn checked_div2(self) -> Option<Self>
pub const fn checked_div2(self) -> Option<Self>
Divide the value by two. Return the previous power of two, if it exists.
- If the integer is equal to 2^(n + 1) for some n ≥ 0, then return
Some(2^n). - If the integer is equal to 2^0, then return
None.