pub enum BasePattern {
Ignore,
Identifier(Identifier),
Product(Arc<Self>, Arc<Self>),
}Expand description
Basic structure of a SimplicityHL value for pattern matching.
Variants
Ignore
Ignore: Match any value.
Used for matching values that are not assigned to a variable.
Identifier(Identifier)
Variable identifier: Match any value and bind it to an identifier.
Product(Arc<Self>, Arc<Self>)
Product: Match product value component-wise.
Implementations
Sourceimpl BasePattern
impl BasePattern
Sourcepub fn product(left: Self, right: Self) -> Self
pub fn product(left: Self, right: Self) -> Self
Construct a product of patterns left and right.
Sourcepub fn as_identifier(&self) -> Option<&Identifier>
pub fn as_identifier(&self) -> Option<&Identifier>
Access the identifier inside an identifier pattern.
Sourcepub fn contains(&self, identifier: &Identifier) -> bool
pub fn contains(&self, identifier: &Identifier) -> bool
Check if the identifier is contained inside the pattern.
Sourcepub fn subsumes(&self, other: &Self) -> bool
pub fn subsumes(&self, other: &Self) -> bool
Check if self subsumes the other pattern.
Subsumption
- Ignore:
_subsumes every pattern. - Identifier:
asubsumesbiffa=b - Product:
(a1, a2)subsumes(b1, b2)iffa1subsumesb1anda2subsumesb2.
Matching
If value v matches pattern p and pattern p' subsumes p,
then v matches p'.
The subsuming pattern is more general than the subsumed pattern.
Sourcepub fn identifiers(&self) -> impl Iterator<Item = &Identifier>
pub fn identifiers(&self) -> impl Iterator<Item = &Identifier>
Get an iterator over all identifiers inside the pattern.
Sourcepub fn contains_all<'a, I>(&self, identifiers: I) -> boolwhere
I: Iterator<Item = &'a Identifier>,
pub fn contains_all<'a, I>(&self, identifiers: I) -> boolwhere
I: Iterator<Item = &'a Identifier>,
Check if all identifiers are contained inside the pattern.
Sourcepub fn covers(&self, other: &Self) -> bool
pub fn covers(&self, other: &Self) -> bool
Check if self covers the other pattern in terms of variable names.
Coverage
Pattern p1 covers pattern p2 if p1 contains all variable names from p2.
Sourcepub fn contains_ignore(&self) -> bool
pub fn contains_ignore(&self) -> bool
Check if the pattern contains an ignore pattern.
Sourcepub fn translate<'brand, P: CoreExt<'brand>>(
&self,
ctx: &Context<'brand>,
to: &Self,
) -> Option<PairBuilder<P>>
pub fn translate<'brand, P: CoreExt<'brand>>( &self, ctx: &Context<'brand>, to: &Self, ) -> Option<PairBuilder<P>>
Compute a Simplicity expression that takes as input a value that matches the self pattern
and that produces as output a value that matches the to pattern.
Panics
The to pattern contains ignore patterns: Every value matches the ignore pattern.
This means there are infinitely many translating expressions from self to to.
For instance, iden, iden & iden, (iden & iden) & iden, and so on.
We enforce a unique translation by banning ignore from the to pattern.